@@ -36,13 +36,14 @@ class accuinsight(Common):
         super().get_file(storage_json_file_name)
 
     def autolog(self, tag=None, best_weights=False, model_monitor=False):
-        global description, endpoint, var_model_file_path, message, thresholds, token, channel_id, run_id, shap_on
+        global description, endpoint, var_model_file_path, message, thresholds, run_id, alarm, alarm_api, shap_on
         description = tag
         endpoint = self.endpoint
         message = self.message
         thresholds = self.thresholds
-        token = self.token
-        channel_id = self.channel_id
+        alarm = self.workspace_alarm
+        alarm_api = self.workspace_alarm_api
+
         if best_weights:
             best_weights_on = True
         else:
@@ -167,7 +168,6 @@ class accuinsight(Common):
                 
                 # Using best_weights
                 if best_weights_on:
-                    
                     # update best_weights
                     self.epochs_since_last_save += 1
                     if self.epochs_since_last_save >= 1:
@@ -190,8 +190,7 @@ class accuinsight(Common):
                 else:
                     self.last_epoch_metric = logs.get(self.monitor)
                     self.best_epochs = epoch + 1
-                    current = logs.get(self.monitor)
-                    self.current_value = current
+                    self.current_value = logs.get(self.monitor)
 
                 # model save path
                 run_id = self.model_summary['model_type'] + '-' + self.model_summary['run_id']
@@ -266,8 +265,8 @@ class accuinsight(Common):
                                           current_value=self.current_value,
                                           message=message,
                                           thresholds=thresholds,
-                                          token=token,
-                                          channel_id=channel_id)
+                                          alarm_object=alarm,
+                                          alarm_api=alarm_api)
                 env_value = get_os_env('ENV')
                 modeler_rest = LifecycleRestApi(env_value[LcConst.BACK_END_API_URL],
                                                 env_value[LcConst.BACK_END_API_PORT],
